==> testsuite-3.0.57-beta1.tar.gz: testsuite/modules/list_packages/src/GetNpmRegisteryClient.php <==
<?php

namespace Drupal\list_packages;

use Drupal\Component\Serialization\Json;
use Drupal\Core\Extension\ModuleExtensionList;
use Drupal\Core\Http\ClientFactory;
use Drupal\testsuite\BaseFileService;

/**
 * The client for accessing packagist.org.
 */
class GetNpmRegisteryClient extends BaseFileService {

  /**
   * The client.
   *
   * @var \GuzzleHttp\Client
   */
  protected $client;

  /**
   * The module handler.
   *
   * @var \Drupal\Core\Extension\ModuleExtensionList
   */
  protected $moduleExtensionList;

  /**
   * CatFactsClient constructor.
   *
   * @param \Drupal\Core\Http\ClientFactory $httpClientFactory
   *   The client factory.
   * @param \Drupal\Core\Extension\ModuleExtensionList $moduleExtensionList
   *   The module handler service.
   */
  public function __construct(
    ClientFactory $httpClientFactory,
    ModuleExtensionList $moduleExtensionList
  ) {
    $version = $moduleExtensionList->getExtensionInfo('testsuite')['version'];
    $this->client = $httpClientFactory->fromOptions(
      [
        'base_uri' => 'https://registry.npmjs.org/',
        "headers" => [
          "User-Agent" => "drupal/testsuite v$version",
          "Content-Type" => "application/x-www-form-urlencoded",
        ],
      ]
    );
  }

  /**
   * Gets the latest package information from registry.npmjs.org.
   *
   * @param string $package
   *   The package name.
   * @param string $version
   *   The package version.
   *
   * @return array
   *   The status and message.
   */
  public function getNpmRegisteryInfo($package, $version = NULL) {
    try {
      $response = $this->client->get($package . "/" . $version, []);
      $data = Json::decode($response->getBody());
      $data['status'] = TRUE;
      return $data;
    }
    catch (\Exception $e) {
      return ['status' => FALSE, 'message' => $e->getMessage()];
    }
  }

  /**
   * Gets a list of vulnerabilities registry.npmjs.org.
   *
   * @param string $packages
   *   The package name.
   *
   * @return array
   *   The status and message.
   */
  public function getVulnerabilities($packages) {
    try {
      $response = $this->client->post(
        "/-/npm/v1/security/audits",
        [
          'form_params' => $packages,
        ]
      );
      $data = Json::decode($response->getBody());
      $data['status'] = TRUE;
      return $data;
    }
    catch (\Exception $e) {
      return ['status' => FALSE, 'message' => $e->getMessage()];
    }
  }

  /**
   * Gets a list of all vulnerabilities registry.npmjs.org.
   *
   * @return array
   *   The status and message.
   */
  public function getVulnerabilitiesBulk() {
    try {
      $response = $this->client->post(
        "/-/npm/v1/security/advisories/bulk", []
      );
      $data = Json::decode($response->getBody());
      $data['status'] = TRUE;
      return $data;
    }
    catch (\Exception $e) {
      return ['status' => FALSE, 'message' => $e->getMessage()];
    }
  }

}

==> testsuite-3.0.61-beta1.tar.gz: testsuite/modules/list_packages/src/GetNpmRegisteryClient.php <==
<?php

namespace Drupal\list_packages;

use Drupal\Component\Serialization\Json;
use Drupal\Core\Extension\ModuleExtensionList;
use Drupal\Core\Http\ClientFactory;
use Drupal\testsuite\BaseFileService;

/**
 * The client for accessing packagist.org.
 */
class GetNpmRegisteryClient extends BaseFileService {

  /**
   * The client.
   *
   * @var \GuzzleHttp\Client
   */
  protected $client;

  /**
   * The module handler.
   *
   * @var \Drupal\Core\Extension\ModuleExtensionList
   */
  protected $moduleExtensionList;

  /**
   * CatFactsClient constructor.
   *
   * @param \Drupal\Core\Http\ClientFactory $httpClientFactory
   *   The client factory.
   * @param \Drupal\Core\Extension\ModuleExtensionList $moduleExtensionList
   *   The module handler service.
   */
  public function __construct(
    ClientFactory $httpClientFactory,
    ModuleExtensionList $moduleExtensionList,
  ) {
    $version = $moduleExtensionList->getExtensionInfo('testsuite')['version'];
    $this->client = $httpClientFactory->fromOptions(
      [
        'base_uri' => 'https://registry.npmjs.org/',
        "headers" => [
          "User-Agent" => "drupal/testsuite v$version",
          "Content-Type" => "application/x-www-form-urlencoded",
        ],
      ]
    );
  }

  /**
   * Gets the latest package information from registry.npmjs.org.
   *
   * @param string $package
   *   The package name.
   * @param string $version
   *   The package version.
   *
   * @return array
   *   The status and message.
   */
  public function getNpmRegisteryInfo($package, $version = NULL) {
    try {
      $response = $this->client->get($package . "/" . $version, []);
      $data = Json::decode($response->getBody());
      $data['status'] = TRUE;
      return $data;
    }
    catch (\Exception $e) {
      return ['status' => FALSE, 'message' => $e->getMessage()];
    }
  }

  /**
   * Gets a list of vulnerabilities registry.npmjs.org.
   *
   * @param string $packages
   *   The package name.
   *
   * @return array
   *   The status and message.
   */
  public function getVulnerabilities($packages) {
    try {
      $response = $this->client->post(
        "/-/npm/v1/security/audits",
        [
          'form_params' => $packages,
        ]
      );
      $data = Json::decode($response->getBody());
      $data['status'] = TRUE;
      return $data;
    }
    catch (\Exception $e) {
      return ['status' => FALSE, 'message' => $e->getMessage()];
    }
  }

  /**
   * Gets a list of all vulnerabilities registry.npmjs.org.
   *
   * @return array
   *   The status and message.
   */
  public function getVulnerabilitiesBulk() {
    try {
      $response = $this->client->post(
        "/-/npm/v1/security/advisories/bulk", []
      );
      $data = Json::decode($response->getBody());
      $data['status'] = TRUE;
      return $data;
    }
    catch (\Exception $e) {
      return ['status' => FALSE, 'message' => $e->getMessage()];
    }
  }

}
